#!/usr/bin/env python

"""
DOM wrapper around libxml2.
"""

import xml.dom

class Attribute(object):

    def __init__(self, node):
        self._node = node

class Node(object):

    _nodeTypes = {
        "attribute" : xml.dom.Node.ATTRIBUTE_NODE,
        "comment" : xml.dom.Node.COMMENT_NODE,
        "document_xml" : xml.dom.Node.DOCUMENT_NODE,
        "doctype" : xml.dom.Node.DOCUMENT_TYPE_NODE,
        "element" : xml.dom.Node.ELEMENT_NODE,
        "entity" : xml.dom.Node.ENTITY_NODE,
        "entity_ref" : xml.dom.Node.ENTITY_REFERENCE_NODE,
        "notation" : xml.dom.Node.NOTATION_NODE,
        "pi" : xml.dom.Node.PROCESSING_INSTRUCTION_NODE,
        "text" : xml.dom.Node.TEXT_NODE
        }

    def __init__(self, node):
        self._node = node

    def _ownerDocument(self):
        return self._node.doc

    def _nodeType(self):
        return self._nodeTypes[self._node.type]

    def _childNodes(self):
        child_nodes = []
        child_node = self._node.children
        while child_node is not None:
            child_nodes.append(
                self.__class__(child_node))
            child_node = child_node.next
        return child_nodes

    def _attributes(self):
        attributes = []
        attribute = self._node.properties
        while attribute is not None:
            attributes.append(
                Attribute(attribute))
            attribute = attribute.next
        return attributes

    def _tagName(self):
        if self._node.type == "element":
            return self._node.name
        else:
            return None

    def _namespaceURI(self):
        if self._node.type == "element":
            return self._node.ns().content
        else:
            return None

    nodeType = property(_nodeType)
    ownerDocument = property(_ownerDocument)
    childNodes = property(_childNodes)
    attributes = property(_attributes)
    tagName = property(_tagName)
    namespaceURI = property(_namespaceURI)

# vim: tabstop=4 expandtab shiftwidth=4
